@@ -16,16 +16,24 @@
 #include "common/defines.h"
 #include <cstdint>
 
+#if WASMEDGE_OS_WINDOWS
+#define WASMEDGE_EXPORT __declspec(dllexport)
+#else
+#define WASMEDGE_EXPORT [[gnu::visibility("default")]]
+#endif
+
 namespace WasmEdge {
 
 class Allocator {
 public:
-  static uint8_t *allocate(uint32_t PageCount) noexcept;
+  WASMEDGE_EXPORT static uint8_t *allocate(uint32_t PageCount) noexcept;
 
-  static uint8_t *resize(uint8_t *Pointer, uint32_t OldPageCount,
-                         uint32_t NewPageCount) noexcept;
+  WASMEDGE_EXPORT static uint8_t *resize(uint8_t *Pointer,
+                                         uint32_t OldPageCount,
+                                         uint32_t NewPageCount) noexcept;
 
-  static void release(uint8_t *Pointer, uint32_t PageCount) noexcept;
+  WASMEDGE_EXPORT static void release(uint8_t *Pointer,
+                                      uint32_t PageCount) noexcept;
 
   static uint8_t *allocate_chunk(uint64_t Size) noexcept;
   static void release_chunk(uint8_t *Pointer, uint64_t Size) noexcept;
