@@ -329,6 +329,7 @@ WASI_NN_OPENVINO = "wasi_nn-openvino"
 WASI_CRYPTO = "wasi_crypto"
 WASI_NN_PYTORCH = "wasi_nn-pytorch"
 WASI_NN_TENSORFLOW_LITE = "wasi_nn-tensorflowlite"
+WASI_NN_GGML = "wasi_nn-ggml"
 WASMEDGE_TENSORFLOW_PLUGIN = WASMEDGE.lower() + "_" + TENSORFLOW
 WASMEDGE_TENSORFLOW_LITE_PLUGIN = WASMEDGE.lower() + "_" + TENSORFLOW_LITE_P
 WASMEDGE_IMAGE_PLUGIN = WASMEDGE.lower() + "_" + IMAGE
@@ -339,6 +340,7 @@ PLUGINS_AVAILABLE = [
     WASI_CRYPTO,
     WASI_NN_PYTORCH,
     WASI_NN_TENSORFLOW_LITE,
+    WASI_NN_GGML,
     WASMEDGE_TENSORFLOW_PLUGIN,
     WASMEDGE_TENSORFLOW_LITE_PLUGIN,
     WASMEDGE_IMAGE_PLUGIN,
@@ -352,9 +354,14 @@ SUPPORTTED_PLUGINS = {
     "manylinux2014" + "arm64" + WASI_CRYPTO: VersionString("0.10.1-rc.1"),
     "ubuntu20.04" + "x86_64" + WASI_NN_OPENVINO: VersionString("0.10.1-alpha.1"),
     "ubuntu20.04" + "x86_64" + WASI_NN_PYTORCH: VersionString("0.11.1-alpha.1"),
+    "ubuntu20.04" + "x86_64" + WASI_NN_GGML: VersionString("0.13.4"),
     "manylinux2014" + "x86_64" + WASI_NN_PYTORCH: VersionString("0.11.2-alpha.1"),
     "manylinux2014" + "x86_64" + WASI_NN_TENSORFLOW_LITE: VersionString("0.10.0"),
+    "manylinux2014" + "x86_64" + WASI_NN_GGML: VersionString("0.13.4"),
     "manylinux2014" + "aarch64" + WASI_NN_TENSORFLOW_LITE: VersionString("0.10.0"),
+    "manylinux2014" + "aarch64" + WASI_NN_GGML: VersionString("0.13.4"),
+    "darwin" + "x86_64" + WASI_NN_GGML: VersionString("0.13.4"),
+    "darwin" + "arm64" + WASI_NN_GGML: VersionString("0.13.4"),
     "ubuntu20.04" + "x86_64" + WASI_NN_TENSORFLOW_LITE: VersionString("0.11.2-rc.1"),
     "darwin" + "x86_64" + WASMEDGE_TENSORFLOW_PLUGIN: VersionString("0.13.0"),
     "darwin" + "arm64" + WASMEDGE_TENSORFLOW_PLUGIN: VersionString("0.13.0"),
@@ -412,7 +419,7 @@ case :"${1}": in
     *)
         # Prepending path in case a system-installed wasmedge needs to be overridden
         if [ -n "${1}" ]; then
-            export PATH="{0}/bin":$PATH
+            export PATH="{0}/bin:$PATH"
         else
             export PATH="{0}/bin"
         fi
@@ -424,7 +431,7 @@ case :"${2}": in
     *)
         # Prepending path in case a system-installed wasmedge libs needs to be overridden
         if [ -n "${2}" ]; then
-            export {2}="{0}/{6}":${2}
+            export {2}="{0}/{6}:${2}"
         else
             export {2}="{0}/{6}"
         fi
@@ -435,7 +442,7 @@ case :"${3}": in
         ;;
     *)
         if [ -n "${3}" ]; then
-            export LIBRARY_PATH="{0}/{6}":$LIBRARY_PATH
+            export LIBRARY_PATH="{0}/{6}:$LIBRARY_PATH"
         else
             export LIBRARY_PATH="{0}/{6}"
         fi
@@ -446,7 +453,7 @@ case :"${4}": in
         ;;
     *)
         if [ -n "${4}" ]; then
-            export C_INCLUDE_PATH="{0}/include":$C_INCLUDE_PATH
+            export C_INCLUDE_PATH="{0}/include:$C_INCLUDE_PATH"
         else
             export C_INCLUDE_PATH="{0}/include"
         fi
@@ -457,7 +464,7 @@ case :"${5}": in
         ;;
     *)
         if [ -n "${5}" ]; then
-            export CPLUS_INCLUDE_PATH="{0}/include":$CPLUS_INCLUDE_PATH
+            export CPLUS_INCLUDE_PATH="{0}/include:$CPLUS_INCLUDE_PATH"
         else
             export CPLUS_INCLUDE_PATH="{0}/include"
         fi
